function [ys,check] = ABK_steadystate(ys,exo)
% function [ys,check] = alpha_steadystate(ys,exo)
% computes the steady state for the alpha.mod and uses a numerical
% solver to do so
% Inputs: 
%   - ys        [vector] vector of initial values for the steady state of
%                   the endogenous variables
%   - exo       [vector] vector of values for the exogenous variables
%
% Output: 
%   - ys        [vector] vector of steady state values fpr the the endogenous variables
%   - check     [scalar] set to 0 if steady state computation worked and to
%                    1 of not (allows to impos restriction on parameters)

global M_   

% read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = deblank(M_.param_names(ii,:));
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end
% initialize indicator
check = 0;

%% 
% bankֲ
sigma=0.94;
theta=0.474910394265250;
gamma=6.399999999999884;
epsilon=5.882352941174504e-04;
% ƫü
alphaK=0.3;
alphaL=0.55;
alphaM=0.15;
beta=1/1.015;
delta=0.02;
eta=9;
omega=0.66;
kappai=1;
zeta=0.2;
zeta0=5.89;
phi=1;
nh=9.849019085822965e-04;
kappa=(eta-1)*omega/((1-omega)*(1-beta*omega));

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ̬
Rstar=1.005;
A=1;
ystar=0.418885954793757;
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ֱ̬ȷ
R=1.015;
mc=(eta-1)/eta;
pi=1;
rd=R-1;
tauK=0;
taustar=0;
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bank Ĳ̬     6

x0=[0.3;1;1.02];
options = optimoptions('fsolve','TolFun',1e-15, 'MaxIter', 1e6);
[xx,fval]=fsolve(@bankss,x0,options,beta, sigma, gamma,  epsilon,theta);

x=xx(1);
Phi=xx(2);
Rb=xx(3);

psi=theta*(1+gamma*x^2/2)*Phi;
mu=beta*(1-sigma+sigma*psi)*(Rb-1/beta);
mud=beta*(1-sigma+sigma*psi)*(1/beta-1.005);
nu=(1-sigma+sigma*psi);

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  bank Ĳ̬    11
xx0=[3];
options = optimoptions('fsolve','TolFun',1e-15, 'MaxIter', 1e8);
[xxx,fval]=fsolve(@nobankss,xx0,options, alphaK,  alphaL,  alphaM,   zeta0, delta,    eta,  zeta,Rb);

Y=xxx(1);

ebar=1;
rk=Rb-1+delta;
aky=(eta-1)/eta*alphaK/rk;
K=aky*Y;
I=delta*K;
Q=1;
L=(alphaL*rk*aky*Y/(alphaK*zeta0))^(1/(1+zeta));
M=alphaM*rk*K/(alphaK*ebar);
Kb=0.75*K;
Kh=0.25*K;
EX=ebar*ystar;
C=Y-delta*K-EX-(beta*Rb-1)*Kh/2;
GDP=C+delta*K+EX-ebar*M;
w=zeta0*L^zeta;
Util=log(C-zeta0*L^(1+zeta)/(1+zeta)   );
welfare=Util/(1-beta);
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  bank ̬  

N=Q*Kb/Phi;
D=(1-1/Phi-x)*Q*Kb;
Dstar=Q*Kb*x/ebar;
tauN=taustar*x*Phi+tauK*Q*Kb;
Omega=beta*(1-sigma+sigma*psi(+1));

%% 

for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'M_.params(' num2str(iter) ') = ' M_.param_names(iter,:) ';' ])
end

NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = deblank(M_.endo_names(ii,:));
  eval(['ys(' int2str(ii) ') = ' varname ';']);
end
